@@ -25,13 +25,15 @@ KJobPrivate::~KJobPrivate()
 }
 
 KJob::KJob(QObject *parent)
-    : QObject(parent), d_ptr(new KJobPrivate)
+    : QObject(parent)
+    , d_ptr(new KJobPrivate)
 {
     d_ptr->q_ptr = this;
 }
 
 KJob::KJob(KJobPrivate &dd, QObject *parent)
-    : QObject(parent), d_ptr(&dd)
+    : QObject(parent)
+    , d_ptr(&dd)
 {
     d_ptr->q_ptr = this;
 }
@@ -40,12 +42,11 @@ KJob::~KJob()
 {
     if (!d_ptr->isFinished) {
         d_ptr->isFinished = true;
-        emit finished(this, QPrivateSignal());
+        Q_EMIT finished(this, QPrivateSignal());
     }
 
     delete d_ptr->speedTimer;
     delete d_ptr->uiDelegate;
-    delete d_ptr;
 }
 
 void KJob::setUiDelegate(KJobUiDelegate *delegate)
@@ -87,10 +88,10 @@ void KJob::finishJob(bool emitResult)
     }
 
     // If we are displaying a progress dialog, remove it first.
-    emit finished(this, QPrivateSignal());
+    Q_EMIT finished(this, QPrivateSignal());
 
     if (emitResult) {
-        emit result(this, QPrivateSignal());
+        Q_EMIT result(this, QPrivateSignal());
     }
 
     if (isAutoDelete()) {
@@ -124,7 +125,7 @@ bool KJob::suspend()
     if (!d->suspended) {
         if (doSuspend()) {
             d->suspended = true;
-            emit suspended(this, QPrivateSignal());
+            Q_EMIT suspended(this, QPrivateSignal());
 
             return true;
         }
@@ -139,7 +140,7 @@ bool KJob::resume()
     if (d->suspended) {
         if (doResume()) {
             d->suspended = false;
-            emit resumed(this, QPrivateSignal());
+            Q_EMIT resumed(this, QPrivateSignal());
 
             return true;
         }
@@ -180,7 +181,7 @@ bool KJob::exec()
     const bool wasAutoDelete = isAutoDelete();
     setAutoDelete(false);
 
-    Q_ASSERT(! d->eventLoop);
+    Q_ASSERT(!d->eventLoop);
 
     QEventLoop loop(this);
     d->eventLoop = &loop;
@@ -252,9 +253,12 @@ void KJob::setProcessedAmount(Unit unit, qulonglong amount)
     d->processedAmount[unit] = amount;
 
     if (should_emit) {
-        emit processedAmount(this, unit, amount);
+#if KCOREADDONS_BUILD_DEPRECATED_SINCE(5, 80)
+        Q_EMIT processedAmount(this, unit, amount);
+#endif
+        Q_EMIT processedAmountChanged(this, unit, amount, QPrivateSignal{});
         if (unit == d->progressUnit) {
-            emit processedSize(this, amount);
+            Q_EMIT processedSize(this, amount);
             emitPercent(d->processedAmount[unit], d->totalAmount[unit]);
         }
     }
@@ -268,9 +272,12 @@ void KJob::setTotalAmount(Unit unit, qulonglong amount)
     d->totalAmount[unit] = amount;
 
     if (should_emit) {
-        emit totalAmount(this, unit, amount);
+#if KCOREADDONS_BUILD_DEPRECATED_SINCE(5, 80)
+        Q_EMIT totalAmount(this, unit, amount);
+#endif
+        Q_EMIT totalAmountChanged(this, unit, amount, QPrivateSignal{});
         if (unit == d->progressUnit) {
-            emit totalSize(this, amount);
+            Q_EMIT totalSize(this, amount);
             emitPercent(d->processedAmount[unit], d->totalAmount[unit]);
         }
     }
@@ -287,7 +294,10 @@ void KJob::setPercent(unsigned long percentage)
     Q_D(KJob);
     if (d->percentage != percentage) {
         d->percentage = percentage;
-        emit percent(this, percentage);
+#if KCOREADDONS_BUILD_DEPRECATED_SINCE(5, 80)
+        Q_EMIT percent(this, percentage);
+#endif
+        Q_EMIT percentChanged(this, percentage, QPrivateSignal{});
     }
 }
 
@@ -306,7 +316,10 @@ void KJob::emitPercent(qulonglong processedAmount, qulonglong totalAmount)
         unsigned long oldPercentage = d->percentage;
         d->percentage = 100.0 * processedAmount / totalAmount;
         if (d->percentage != oldPercentage) {
-            emit percent(this, d->percentage);
+#if KCOREADDONS_BUILD_DEPRECATED_SINCE(5, 80)
+            Q_EMIT percent(this, d->percentage);
+#endif
+            Q_EMIT percentChanged(this, d->percentage, QPrivateSignal{});
         }
     }
 }
@@ -319,8 +332,8 @@ void KJob::emitSpeed(unsigned long value)
         connect(d->speedTimer, SIGNAL(timeout()), SLOT(_k_speedTimeout()));
     }
 
-    emit speed(this, value);
-    d->speedTimer->start(5000);   // 5 seconds interval should be enough
+    Q_EMIT speed(this, value);
+    d->speedTimer->start(5000); // 5 seconds interval should be enough
 }
 
 void KJobPrivate::_k_speedTimeout()
@@ -328,7 +341,7 @@ void KJobPrivate::_k_speedTimeout()
     Q_Q(KJob);
     // send 0 and stop the timer
     // timer will be restarted only when we receive another speed event
-    emit q->speed(q, 0);
+    Q_EMIT q->speed(q, 0);
     speedTimer->stop();
 }
 
